@@ -70,7 +70,7 @@ def load_trainer_state(trainer: Trainer, checkpoint: Mapping[str, Any], model: L
                 setattr(callback, key, value)
 
 
-def load_state(run_id: str, model: LightningModule, trainer: Optional[Trainer], filename: str = 'last') -> None:
+def load_state(run_id: str, model: LightningModule, trainer: Optional[Trainer] = None, filename: str = 'last') -> None:
     device = torch.device('cuda') if torch.cuda.device_count() else torch.device('cpu')
 
     checkpoint_path = get_checkpoint_path(run_id, filename)
